<?php
/**
 * bluebiz functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package bluebiz
 */

if ( ! function_exists( 'bluebiz_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bluebiz_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on bluebiz, use a find and replace
	 * to change 'bluebiz' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'bluebiz', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( '<i class="fa fa-bars"></i>', 'bluebiz' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'bluebiz_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // bluebiz_setup
add_action( 'after_setup_theme', 'bluebiz_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bluebiz_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bluebiz_content_width', 640 );
}
add_action( 'after_setup_theme', 'bluebiz_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bluebiz_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'bluebiz' ),
		'id'            => 'sidebar-1',
		'description'   => 'Location: Below Sidebar Top Widget, has two columns 50/50 width.',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'bluebiz_widgets_init' );

function initialize_header_widget() {
	register_sidebar( array(
		'name'          => esc_html__( 'Header Widget', 'bluebiz' ),
		'id'            => 'header-widget',
		'description'   => 'Location: Right side of your website title.',
		'before_widget' => '<div class="header_widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'initialize_header_widget' );

function initialize_sidebar_top_widget() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Top Widget', 'bluebiz' ),
		'id'            => 'sidebar_top_widget',
		'description'   => 'Location: Right side, on top. Full width of the sidebar. Excellent for AdSense!',
		'before_widget' => '<div class="sidebar_top_widget">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'initialize_sidebar_top_widget' );

/**
 * Enqueue scripts and styles.
 */
function bluebiz_enqueue_scripts_and_styles() {
	wp_enqueue_style( 'google_fonts', '//fonts.googleapis.com/css?family=Roboto+Slab|Roboto|Lobster|Oswald', false );
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/inc/font-awesome-4.5.0/css/font-awesome.min.css');
}
add_action( 'wp_enqueue_scripts', 'bluebiz_enqueue_scripts_and_styles' ); 
 
function bluebiz_scripts() {
	
	wp_enqueue_style( 'bluebiz-style', get_stylesheet_uri() );

	wp_enqueue_script( 'bluebiz-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'bluebiz-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bluebiz_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
